summaryrefslogtreecommitdiff
path: root/basic/source
diff options
context:
space:
mode:
authorAndreas Heinisch <andreas.heinisch@yahoo.de>2022-02-21 19:34:57 +0100
committerAndreas Heinisch <andreas.heinisch@yahoo.de>2022-02-21 23:10:46 +0100
commit3ba8b56b32c203326b776b940d20b16eb2340835 (patch)
tree4c63ed35dead8cb1c9e993b83093f1c4badd0ba3 /basic/source
parent02e1be8883a08ab17f3e890a834ab88f13c5867d (diff)
tdf#147089 - Round Integral Division (IDIV) literals to Integer values
Change-Id: Ia243c6117a437d0c6efb33a4e76c5e9ee539fbdc Reviewed-on: https://gerrit.libreoffice.org/c/core/+/130302 Tested-by: Jenkins Reviewed-by: Andreas Heinisch <andreas.heinisch@yahoo.de>
Diffstat (limited to 'basic/source')
-rw-r--r--basic/source/comp/exprnode.cxx4
1 files changed, 2 insertions, 2 deletions
diff --git a/basic/source/comp/exprnode.cxx b/basic/source/comp/exprnode.cxx
index 17bdbca25258..a5fd8dde3cfc 100644
--- a/basic/source/comp/exprnode.cxx
+++ b/basic/source/comp/exprnode.cxx
@@ -296,8 +296,8 @@ void SbiExprNode::FoldConstantsBinaryNode(SbiParser* pParser)
{
double nl = pLeft->nVal;
double nr = pRight->nVal;
- // tdf#141201 - round MOD literals to Integer values
- if (eTok == MOD)
+ // tdf#141201, tdf#147089 - round MOD/IDIV literals to Integer values
+ if (eTok == MOD || eTok == IDIV)
{
nl = rtl::math::round(nl);
nr = rtl::math::round(nr);